==> jsonprettyprint-1.0.0.tar.gz: jsonprettyprint/src/Plugin/Field/FieldFormatter/JSONPrettyPrintFormatter.php <==
<?php

namespace Drupal\jsonprettyprint\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Ergebnis\Json\Printer;

/**
 * Plugin implementation of the 'JSON Pretty' formatter.
 *
 * @FieldFormatter(
 *   id = "jsonprettyprint",
 *   label = @Translation("JSON Pretty Print"),
 *   field_types = {
 *     "string",
 *     "string_long",
 *   }
 * )
 */
class JSONPrettyPrintFormatter extends FormatterBase {

  const indentDefault = "&nbsp;&nbsp;";


  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [
      'indent' => [],
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $form['indent'] = [
      '#type' => 'select',
      '#title' => $this->t('Indent'),
      '#options' => $this->getIndentOptions(),
      '#default_value' => $this->getIndent(),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];

    $indentOptions = $this->getIndentOptions();
    $indent = $this->getIndent();
    $summary[] = $this->t('Indent: %indent', ['%indent' => $indentOptions[$indent]]);

    return $summary;
  }

  /**
   * Get indent.
   *
   * @return string
   *   Returns indent in string format.
   */
  private function getIndent() {
    return $this->getSetting('indent') ?? self::indentDefault;
  }


  /**
   * Get indent options.
   *
   * @return array
   *   Returns indent options in array format.
   */
  private function getIndentOptions() {
    return [
      "  "    => $this->t('2 spaces'),
      "    "  => $this->t('4 spaces'),
      "\t"    => $this->t('1 tab'),
      "\t\t"  => $this->t('2 tabs'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      $value = $item->value;
      if (empty($value)) {
        $value = $item->getValue();
      }


      $json = NULL;
      try {
        $printer = new Printer\Printer();
        $json = $printer->print($value, $this->getIndent());
      }
      catch (\InvalidArgumentException $e) {
        \Drupal::logger('jsonprettyprint')->error($e->getMessage());
      }

      if (!empty($json)) {
        $elements[$delta] = [
          '#type' => 'inline_template',
          '#template' => '<pre class="jsonprettyprint">{{ json }}</pre>',
          '#context' => [
            'json' => $json,
          ],
        ];
      }
      else {
        $elements[$delta] = [
          '#markup' => $value
        ];
      }


    }

    return $elements;
  }

}

==> jsonprettyprint-1.1.1.tar.gz: jsonprettyprint/src/Plugin/Field/FieldFormatter/JSONPrettyPrintFormatter.php <==
<?php

namespace Drupal\jsonprettyprint\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Ergebnis\Json\Printer;

/**
 * Plugin implementation of the 'JSON Pretty' formatter.
 *
 * @FieldFormatter(
 *   id = "jsonprettyprint",
 *   label = @Translation("JSON Pretty Print"),
 *   field_types = {
 *     "string",
 *     "string_long",
 *   }
 * )
 */
class JSONPrettyPrintFormatter extends FormatterBase {

  const INDENT_DEFAULT = "  ";


  /**
   * {@inheritdoc}
   */
  public static function defaultSettings(): array {
    return [
      'indent' => self::INDENT_DEFAULT,
    ] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form = parent::settingsForm($form, $form_state);

    $form['indent'] = [
      '#type' => 'select',
      '#title' => $this->t('Indent'),
      '#options' => $this->getIndentOptions(),
      '#default_value' => $this->getIndent(),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];

    $indentOptions = $this->getIndentOptions();
    $indent = $this->getIndent();
    $summary[] = $this->t('Indent: %indent', ['%indent' => $indentOptions[$indent]]);

    return $summary;
  }

  /**
   * Get indent.
   *
   * @return string
   *   Returns indent in string format.
   */
  private function getIndent() {
    return $this->getSetting('indent') ?? self::INDENT_DEFAULT;
  }


  /**
   * Get indent options.
   *
   * @return array
   *   Returns indent options in array format.
   */
  private function getIndentOptions() {
    return [
      "  "    => $this->t('2 spaces'),
      "    "  => $this->t('4 spaces'),
      "\t"    => $this->t('1 tab'),
      "\t\t"  => $this->t('2 tabs'),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode): array {
    $elements = [];

    foreach ($items as $delta => $item) {
      $value = $item->value;
      if (empty($value)) {
        $value = $item->getValue();
      }


      $json = NULL;
      try {
        $printer = new Printer\Printer();
        $json = $printer->print($value, $this->getIndent());
      }
      catch (\InvalidArgumentException $e) {
        \Drupal::logger('jsonprettyprint')->error($e->getMessage());
      }

      if (!empty($json)) {
        $elements[$delta] = [
          '#type' => 'inline_template',
          '#template' => '<pre class="jsonprettyprint">{{ json }}</pre>',
          '#context' => [
            'json' => $json,
          ],
        ];
      }
      else {
        $elements[$delta] = [
          '#markup' => $value
        ];
      }


    }

    return $elements;
  }

}
